import os
import tempfile


def interact(modules=['n'], mode=''):
    command = 'from fxy.{} import *'

    # BPython
    if mode == 'b':
        commands = '\n'.join([command.format(module) for module in modules]) + '\n'
        with tempfile.NamedTemporaryFile(mode='wt', delete=False) as f:
            f.write(commands)
        os.system(f'{mode}python -i -q -p {f.name}')
        os.system(f'rm {f.name}')
    else:
        # Python & IPython
        commands = '; '.join([command.format(module) for module in modules])
        os.system(f'{mode}python3 -i -c "{commands}"')


def main():

    import argparse
    parser = argparse.ArgumentParser()

    # Mode
    parser.add_argument('-i', '--ipython', action='store_false', default=True, help='IPython.')
    parser.add_argument('-b', '--bpython', action='store_false', default=True, help='BPython.')

    # Module
    parser.add_argument('-n', '--numeric', action='store_false', default=True, help='Numeric.')
    parser.add_argument('-s', '--symbolic', action='store_false', default=True, help='Symbolic.')
    parser.add_argument('-a', '--actuarial', action='store_false', default=True, help='Actuarial.')
    parser.add_argument('-l', '--learning', action='store_false', default=True, help='Learning.')
    parser.add_argument('-p', '--plotting', action='store_false', default=True, help='Plotting.')

    args = parser.parse_args()

    i = not args.ipython
    b = not args.bpython

    n = not args.numeric
    s = not args.symbolic
    a = not args.actuarial
    l = not args.learning
    p = not args.plotting


    if b:
        mode = 'b'
    else:
        # Default is plain IPython shell, cause more common.
        mode = 'i'

    # Default is MPMath for "calculator"
    modules = ['n']

    if s:
        modules.append('s')
    if a:
        modules.append('a')
    if l:
        modules.append('l')
    if p:
        modules.append('p')

    interact(modules, mode)

if __name__ == '__main__':
    main()



from setuptools import find_packages, setup

with open('README.rst', 'r') as f:
    long_description = f.read()

setup(
    name='fxy',
    version='0.3.3',
    description='Convenience imports and scientific functions.',
    long_description=long_description,
    url='https://github.com/mindey/fxy',
    author='Mindey',
    author_email='mindey@qq.com',
    license='UNLICENSE',
    packages = find_packages(exclude=['docs', 'tests*']),
    install_requires=['mpmath', 'bpython', 'ipython', 'sympy'],
    extras_require = {
        'test': ['coverage', 'pytest', 'pytest-cov'],
        'shells': ['bpython', 'ipython'],
        'main': ["bpython", "ipython", "sympy", "xarray", "scipy", "statsmodels", "sklearn", "matplotlib", "seaborn"],
        'all': ["bpython", "ipython"] + ["sympy", "xarray", "scipy", "statsmodels", "sklearn", "matplotlib", "seaborn"] + ["xgboost"]
    },
    zip_safe=False,
    entry_points = {
        'console_scripts': [
            'fxy=fxy:main'
        ],
    }
)



from sympy import symbols, integrate
from sympy.functions.elementary.piecewise import Piecewise
from sympy.functions import Abs
from scipy import constants as const

h = symbols('altitude')

# https://en.wikipedia.org/w/index.php?title=Density_of_air&oldid=862508599#Altitude
standard_values = {
    'standard_sea_level_pressure': const.atm,
    'standard_sea_level_temperature': const.zero_Celsius,#+15.0,
    'earth_surface_gravitational_acceleration': const.g,
    'universal_gas_constant': const.R,
    'molar_mass_of_dry_air': const.physical_constants[
        'molar volume of ideal gas (273.15 K, 101.325 kPa)'][0],
    #0.0289644 # Kg/mol at sea, 15'C.
}

p0, T0, g, R, M = symbols(','.join(standard_values.keys()))

# Temperature Lapse rates
L_atmosphere = Piecewise(
    (0.0065, h <=11000),  # troposphere
    (0, h <=20000),       # tropopause
    (-0.0017, h <=50000), # stratosphere
    (0, h <=55000),       # stratopause
    (0.00375, h <=80000), # mesosphere
    (0, h <=90000),       # mesopause
    (-0.0048, h<=527343), # thermosphere to point where it is 2000'C.
    (0, h > 527343)       # -exosphere-
)

# http://www.physicalgeography.net/fundamentals/7b.html
T_atmospehre = T0.subs(standard_values) - integrate(L_atmosphere)

# https://en.wikipedia.org/w/index.php?title=Barometric_formula&oldid=838719040#Pressure_equations
# P_atmosphere = Piecewise(
#     (1, L_atmosphere == 0),
#     (2, L_atmosphere != 0)
# )
# D_atmosphere = (P_atmosphere*M)/(R*T_atmospehre)
